TensorRT-LLM Inference
Orchestra-Research/AI-Research-SKILLs
Optimizes and serves LLMs on NVIDIA GPUs with TensorRT-LLM, covering quantization, in-flight batching, multi-GPU parallelism and the trtllm-serve command.
Builds a fused row-wise softmax kernel for Triton-Ascend that reads and writes each row once, handling padding, strides and masked loads on Ascend NPUs.
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill build-triton-ascend-fused-softmax -a claude-codeProject install by default; add -g for ~/.claude/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit build-triton-ascend-fused-softmax --agent claude-codeProject scope by default; add --scope user for a personal install. Needs GitHub CLI 2.90.0 or later (public preview).
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .claude/skills && cp -r skills-src/skills/build-triton-ascend-fused-softmax .claude/skills/build-triton-ascend-fused-softmax && rm -rf skills-srcUse ~/.claude/skills/ instead of .claude/skills for a personal install. The folder must contain SKILL.md.
Claude Code skills documentation · loads skills from .claude/skills/
Install the "build-triton-ascend-fused-softmax" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/build-triton-ascend-fused-softmax into .claude/skills/build-triton-ascend-fused-softmax/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "build-triton-ascend-fused-softmax", then confirm the skill loads.Claude Code copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$skill-installer install https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/build-triton-ascend-fused-softmaxType this inside Codex. $skill-installer <name> installs a curated skill from openai/skills. The installer writes to $CODEX_HOME/skills (default ~/.codex/skills). Restart Codex if the skill does not show up.
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill build-triton-ascend-fused-softmax -a codexProject install goes to .agents/skills/; add -g for ~/.codex/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit build-triton-ascend-fused-softmax --agent codexProject scope by default (.agents/skills/); add --scope user for a personal install.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .agents/skills && cp -r skills-src/skills/build-triton-ascend-fused-softmax .agents/skills/build-triton-ascend-fused-softmax && rm -rf skills-srcUse ~/.agents/skills/ instead of .agents/skills for a personal install.
Codex skills documentation · loads skills from .agents/skills/
Install the "build-triton-ascend-fused-softmax" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/build-triton-ascend-fused-softmax into .agents/skills/build-triton-ascend-fused-softmax/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "build-triton-ascend-fused-softmax", then confirm the skill loads.Codex copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill build-triton-ascend-fused-softmax -a cursorProject install goes to .agents/skills/; add -g for ~/.cursor/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit build-triton-ascend-fused-softmax --agent cursorProject scope by default (.agents/skills/); add --scope user for a personal install.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .cursor/skills && cp -r skills-src/skills/build-triton-ascend-fused-softmax .cursor/skills/build-triton-ascend-fused-softmax && rm -rf skills-srcUse ~/.cursor/skills/ instead of .cursor/skills for a personal install.
Cursor skills documentation · loads skills from .cursor/skills/, .agents/skills/, .claude/skills/, .codex/skills/
Install the "build-triton-ascend-fused-softmax" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/build-triton-ascend-fused-softmax into .cursor/skills/build-triton-ascend-fused-softmax/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "build-triton-ascend-fused-softmax", then confirm the skill loads.Cursor copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$ gemini skills install https://github.com/Krusty84/triton-ascend-agent-dev-kit.git --path skills/build-triton-ascend-fused-softmax--scope user (default) or --scope workspace; --path is the subfolder of the repo that holds the skill; --consent skips the security confirmation prompt.
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill build-triton-ascend-fused-softmax -a gemini-cliProject install goes to .agents/skills/; add -g for ~/.gemini/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit build-triton-ascend-fused-softmax --agent gemini-cliProject scope by default (.agents/skills/); add --scope user for a personal install.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .gemini/skills && cp -r skills-src/skills/build-triton-ascend-fused-softmax .gemini/skills/build-triton-ascend-fused-softmax && rm -rf skills-srcUse ~/.gemini/skills/ instead of .gemini/skills for a personal install, then run /skills reload.
Gemini CLI skills documentation · loads skills from .gemini/skills/, .agents/skills/
Install the "build-triton-ascend-fused-softmax" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/build-triton-ascend-fused-softmax into .gemini/skills/build-triton-ascend-fused-softmax/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "build-triton-ascend-fused-softmax", then confirm the skill loads.Gemini CLI copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit build-triton-ascend-fused-softmaxInstalls for Copilot at project scope by default; add --scope user for a personal install. Preview a skill first with gh skill preview. Needs GitHub CLI 2.90.0 or later (public preview).
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill build-triton-ascend-fused-softmax -a github-copilotProject install goes to .agents/skills/; add -g for ~/.copilot/skills/.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .github/skills && cp -r skills-src/skills/build-triton-ascend-fused-softmax .github/skills/build-triton-ascend-fused-softmax && rm -rf skills-srcUse ~/.copilot/skills/ instead of .github/skills for a personal install. Commit .github/skills so cloud agent and code review can use it.
GitHub Copilot skills documentation · loads skills from .github/skills/, .claude/skills/, .agents/skills/
Install the "build-triton-ascend-fused-softmax" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/build-triton-ascend-fused-softmax into .github/skills/build-triton-ascend-fused-softmax/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "build-triton-ascend-fused-softmax", then confirm the skill loads.GitHub Copilot copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill build-triton-ascend-fused-softmax -a opencodeOpenCode documents no install command of its own. Project install goes to .agents/skills/; add -g for ~/.config/opencode/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit build-triton-ascend-fused-softmax --agent opencodeProject scope by default (.agents/skills/); add --scope user for a personal install.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .opencode/skills && cp -r skills-src/skills/build-triton-ascend-fused-softmax .opencode/skills/build-triton-ascend-fused-softmax && rm -rf skills-srcUse ~/.config/opencode/skills/ instead of .opencode/skills for a personal install.
OpenCode skills documentation · loads skills from .opencode/skills/, .claude/skills/, .agents/skills/
Install the "build-triton-ascend-fused-softmax" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/build-triton-ascend-fused-softmax into .opencode/skills/build-triton-ascend-fused-softmax/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "build-triton-ascend-fused-softmax", then confirm the skill loads.OpenCode copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
build-triton-ascend-fused-softmaxBuilds a fused row-wise softmax kernel for Triton-Ascend that reads and writes each row once, handling padding, strides and masked loads on Ascend NPUs.
This skill shows how to write a softmax kernel over the last dimension of a two-dimensional tensor for Triton-Ascend, fusing the max, exponentiation, sum and normalization steps so each input row is read once and each output row is written once. The steps are to treat the input as n_rows by n_cols and keep its row stride, set BLOCK_SIZE to the next power of two at or above n_cols, and let each program handle rows spaced by the program count.
Rows are loaded padded with -inf so the padding cannot affect the maximum or the denominator, the row maximum is subtracted before exponentiation, and the result is stored with the original mask. Guardrails say to reject zero-column inputs and shapes whose padded row exceeds on-chip resources. To verify, compare against torch.softmax over dim 1 with tolerances suited to the dtype, and test odd shapes such as 1823 by 781, very small rows and rows near the largest BLOCK_SIZE.
5 steps, taken from the first numbered list in SKILL.md.
Read from SKILL.md and the folder at commit 4ab5ee7. It shows what the files ask for, not the result of running them.
Pre-approves nothing: there is no allowed-tools line, so your agent's usual permission prompts apply.
From allowed-tools in the SKILL.md frontmatter.
No scripts in the folder and no shell commands in SKILL.md (its code samples are python).
From the folder's file list and the shell code blocks in SKILL.md.
No URLs in SKILL.md.
From URLs in SKILL.md, links to its own repository left out.
Names no API keys, tokens, secrets or passwords.
From names ending in _API_KEY, _TOKEN, _SECRET, _KEY or _PASSWORD in SKILL.md.
Triton-Ascend Fused Softmax loads about 636 tokens when it runs. Until then it costs about 88 tokens; SKILL.md has 178 words of instructions outside code blocks.
Estimates: characters ÷ 4, the usual rule of thumb; real counts depend on the model's tokenizer. Scripts and assets cost tokens only if the agent reads them.
The automated check found no risky patterns in SKILL.md.
Automated static check — not a guarantee. Review scripts before installing. It scans the text of SKILL.md for risky patterns (piping downloads into a shell, reading credential files, hidden Unicode, destructive commands); files beside SKILL.md are not scanned.
The full file from Krusty84/triton-ascend-agent-dev-kit at commit 4ab5ee7, republished under its Apache-2.0 licence (© Krusty84). 178 words, ~636 tokens.
.claude/skills/build-triton-ascend-fused-softmax/SKILL.md (or your agent's skills folder).Compute softmax across the last dimension while reading each input row once and writing each output row once.
@triton.jit
def softmax_kernel(out, x, x_stride, out_stride, n_rows, n_cols,
BLOCK_SIZE: tl.constexpr):
first_row = tl.program_id(0)
row_step = tl.num_programs(0)
cols = tl.arange(0, BLOCK_SIZE)
mask = cols < n_cols
for row in tl.range(first_row, n_rows, row_step):
values = tl.load(x + row * x_stride + cols, mask=mask,
other=-float("inf"))
shifted = values - tl.max(values, axis=0)
numerator = tl.exp(shifted)
result = numerator / tl.sum(numerator, axis=0)
tl.store(out + row * out_stride + cols, result, mask=mask)
def softmax(x):
assert x.ndim == 2
n_rows, n_cols = x.shape
block = triton.next_power_of_2(n_cols)
out = torch.empty_like(x)
programs = min(32, n_rows)
softmax_kernel[(programs,)](
out, x, x.stride(0), out.stride(0), n_rows, n_cols,
BLOCK_SIZE=block,
)
return outCompare with torch.softmax(x, dim=1) using dtype-appropriate tolerances. Test irregular dimensions such as 1823 by 781, very small rows, and rows near the largest supported BLOCK_SIZE.
© Krusty84, Apache-2.0. Rendered from Markdown: HTML in the file is shown as text, images as links, and headings moved down two levels. Raw file
Just SKILL.md in skills/build-triton-ascend-fused-softmax of Krusty84/triton-ascend-agent-dev-kit.
Open the folder on GitHubat commit 4ab5ee7
Triton-Ascend Fused Softmax next to the 5 skills that share the most tags, products or categories with it. Stars are the repository's; “used in” counts other GitHub owners with a copy.
| Skill | Stars | Used in | Tokens | Auto-check | Licence | Repo updated |
|---|---|---|---|---|---|---|
| Triton-Ascend Fused Softmax this skillKrusty84/triton-ascend-agent-dev-kit | 106 | — | ~636 | Automated safety check: Pass | Apache-2.0 | |
| TensorRT-LLM InferenceOrchestra-Research/AI-Research-SKILLs | 13k | 4 repos | ~1.3k | Automated safety check: Pass | MIT | |
| LLM Serving Framework BenchmarkBBuf/AI-Infra-Auto-Driven-SKILLS | 938 | — | ~7.5k | Automated safety check: Pass | None | |
| Magpie Kernel Evaluatoramd/skills | 408 | — | ~2.3k | Automated safety check: Pass | MIT | |
| Paddle Design CompilerPaddlePaddle/Paddle | 24k | — | ~3.6k | Automated safety check: Pass | Apache-2.0 | |
| Graphsignalgraphsignal/graphsignal | 257 | — | ~6.3k | Automated safety check: Pass | Apache-2.0 |
Orchestra-Research/AI-Research-SKILLs
Optimizes and serves LLMs on NVIDIA GPUs with TensorRT-LLM, covering quantization, in-flight batching, multi-GPU parallelism and the trtllm-serve command.
BBuf/AI-Infra-Auto-Driven-SKILLS
Compares SGLang, vLLM, TensorRT-LLM and TokenSpeed on one model and workload, searching server flags to find the best deployment command within a latency SLA.
amd/skills
Benchmarks LLM inference and drives GPU kernel optimization with Magpie.
PaddlePaddle/Paddle
A skill your agent uses when working with Paddle 3.0 compiler full pipeline: SOT (Symbolic Opcode Translator) for bytecode-level dy2st graph capture, PIR (Paddle IR) for SSA-based intermediate…
graphsignal/graphsignal
Profile AI inference workloads (vLLM, SGLang, TensorRT-LLM, PyTorch, any GPU application) with the Graphsignal profiler and read the results from its local /signals JSON endpoint.
huggingface/skills
Trains and fine-tunes object detection, image classification and SAM or SAM2 segmentation models on Hugging Face Jobs cloud GPUs and saves the results to the Hub.
Krusty84/triton-ascend-agent-dev-kit
Implements request-to-token-pool copies for Triton kernels on Ascend NPUs, replacing loop-carried vector offsets with fixed-offset block loops that compile reliably.
Krusty84/triton-ascend-agent-dev-kit
Writes a Triton kernel pattern for Ascend NPU that gathers several indexed token rows per program into an on-chip buffer and stores one contiguous output tile, for MoE-style token reordering.
Krusty84/triton-ascend-agent-dev-kit
Builds Triton-Ascend kernels that pack sorted token assignments into fixed expert-capacity tensors, restore top-k outputs and compute router-weight gradients on Ascend NPUs.
Krusty84/triton-ascend-agent-dev-kit
Guides building a FlashAttention-v2-style fused forward attention kernel for Triton-Ascend on Ascend NPU, with online softmax, causal staging and float32 accumulation.
Krusty84/triton-ascend-agent-dev-kit
Build a fused forward LayerNorm kernel for Triton-Ascend with row-wise mean and variance reductions, float32 accumulation, affine weight and bias, and masked feature tiles.
Krusty84/triton-ascend-agent-dev-kit
Build Ascend-friendly MoE gather, scatter, and router-weight-gradient kernels with vector-core-sized grids, UB-aware row/column tiling, and CANN slice extensions.
Works with
Categories
Builds a fused row-wise softmax kernel for Triton-Ascend that reads and writes each row once, handling padding, strides and masked loads on Ascend NPUs. This skill shows how to write a softmax kernel over the last dimension of a two-dimensional tensor for Triton-Ascend, fusing the max, exponentiation, sum and normalization steps so each input row is read once and each output row is written once. The steps are to treat the input as n_rows by n_cols and keep its row stride, set BLOCK_SIZE to the next power of two at or above n_cols, and let each program handle rows spaced by the program count.
Triton-Ascend Fused Softmax fits situations like: fusing max, exponentiation, sum and normalization for a 2-D tensor on an Ascend NPU; adapting the row-wise reduction pattern to a similar operator; checking a softmax kernel's padding, stride and mask handling.
Run `npx skills add Krusty84/triton-ascend-agent-dev-kit --skill build-triton-ascend-fused-softmax -a claude-code`. Or copy the skill folder (skills/build-triton-ascend-fused-softmax in Krusty84/triton-ascend-agent-dev-kit) into .claude/skills/build-triton-ascend-fused-softmax in your project. Claude Code loads it when a task matches its description.
Run `npx skills add Krusty84/triton-ascend-agent-dev-kit --skill build-triton-ascend-fused-softmax -a codex`. Or copy the skill folder (skills/build-triton-ascend-fused-softmax in Krusty84/triton-ascend-agent-dev-kit) into .agents/skills/build-triton-ascend-fused-softmax in your project. Codex loads it when a task matches its description.
Cursor, Gemini CLI, GitHub Copilot and OpenCode also load SKILL.md folders. With the skills CLI, run `npx skills add Krusty84/triton-ascend-agent-dev-kit --skill build-triton-ascend-fused-softmax -a cursor` (or -a gemini-cli, github-copilot or opencode for the others). To copy it by hand, put the folder in .cursor/skills/build-triton-ascend-fused-softmax, .gemini/skills/build-triton-ascend-fused-softmax, .github/skills/build-triton-ascend-fused-softmax and .opencode/skills/build-triton-ascend-fused-softmax in your project.
SKILL.md names no scripts, command-line tools or credentials: Triton-Ascend Fused Softmax is instructions for the agent only. Our summary lists: Triton-Ascend and an Ascend NPU; PyTorch, for the torch.softmax comparison.
SKILL.md contains no URLs. Any network use would come from the scripts or tools the agent runs. This is read from the text; nothing was executed.
Our automated static check of SKILL.md found no risky patterns, such as piping downloads into a shell, reading credential files or hidden Unicode. It is not a guarantee. Review the folder before installing.
Triton-Ascend Fused Softmax is published under the Apache-2.0 licence (the repository's licence). It allows redistribution, so the full SKILL.md is shown on this page.
About 636 tokens (SKILL.md is roughly 2.5k characters). Agents keep only the skill's name and description in context until a task matches; then they load SKILL.md in full.
Skills that share tags, products or a category with Triton-Ascend Fused Softmax: TensorRT-LLM Inference (Orchestra-Research/AI-Research-SKILLs, 13k stars), LLM Serving Framework Benchmark (BBuf/AI-Infra-Auto-Driven-SKILLS, 938 stars), Magpie Kernel Evaluator (amd/skills, 408 stars) and Paddle Design Compiler (PaddlePaddle/Paddle, 24k stars). The comparison table on this page puts their stars, adoption, token cost, safety result and licence side by side.
Krusty84 (a GitHub user) maintains it in Krusty84/triton-ascend-agent-dev-kit, which has 106 GitHub stars. The repository holds 23 skills in this directory. The repository was last updated on August 15, 2026.
Source: Krusty84/triton-ascend-agent-dev-kit on GitHub. Facts on this page come from the repository at the commit we read; the author's words are quoted as theirs.